==> efibootmgr-0.9.0.tar.gz: efibootmgr-0.9.0/src/include/disk.h <==
/*
  disk.[ch]
 
  Copyright (C) 2001 Dell Computer Corporation <Matt_Domsch@dell.com>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DISK_H
#define _DISK_H

#include <sys/ioctl.h>
#include <stdint.h>

/* Snagged from linux/include/asm-ia64/ioctl.h */
#define _IOC_NRBITS     8
#define _IOC_TYPEBITS   8
#define _IOC_SIZEBITS   14
#define _IOC_DIRBITS    2

#define _IOC_NRMASK     ((1 << _IOC_NRBITS)-1)
#define _IOC_TYPEMASK   ((1 << _IOC_TYPEBITS)-1)
#define _IOC_SIZEMASK   ((1 << _IOC_SIZEBITS)-1)
#define _IOC_DIRMASK    ((1 << _IOC_DIRBITS)-1)

#define _IOC_NRSHIFT    0
#define _IOC_TYPESHIFT  (_IOC_NRSHIFT+_IOC_NRBITS)
#define _IOC_SIZESHIFT  (_IOC_TYPESHIFT+_IOC_TYPEBITS)
#define _IOC_DIRSHIFT   (_IOC_SIZESHIFT+_IOC_SIZEBITS)

/*
 * Direction bits.
 */
#define _IOC_NONE       0U
#define _IOC_WRITE      1U
#define _IOC_READ       2U

#define _IOC(dir,type,nr,size) \
        (((dir)  << _IOC_DIRSHIFT) | \
         ((type) << _IOC_TYPESHIFT) | \
         ((nr)   << _IOC_NRSHIFT) | \
         ((size) << _IOC_SIZESHIFT))

/* used to create numbers */
#define _IO(type,nr)            _IOC(_IOC_NONE,(type),(nr),0)


/* Snagged from linux/include/linux/fs.h */
#define BLKGETSIZE _IO(0x12,96)      /* return device size */


enum _bus_type {bus_type_unknown, isa, pci};
enum _interface_type {interface_type_unknown,
		      ata, atapi, scsi, usb,
		      i1394, fibre, i2o, md,
		      virtblk, nvme};


unsigned int lcm(unsigned int x, unsigned int y);

int disk_get_pci(int fd,
		 int *interface_type,
		 unsigned char *bus,
		 unsigned char *device,
		 unsigned char *function);

struct disk_info {
	int interface_type;
	unsigned int controllernum;
	unsigned int disknum;
	unsigned char part;
	uint64_t major;
	unsigned char minor;
};

int disk_info_from_fd(int fd, struct disk_info *info);


int disk_get_partition_info (int fd, 
			     uint32_t num,
			     uint64_t *start, uint64_t *size,
			     char *signature,
			     uint8_t *mbr_type, uint8_t *signature_type);


int disk_get_size(int fd, long *size);
int get_sector_size(int fd);


#endif

==> efibootmgr_0.11.0.orig.tar.gz: efibootmgr-0.11.0/src/include/disk.h <==
/*
  disk.[ch]
 
  Copyright (C) 2001 Dell Computer Corporation <Matt_Domsch@dell.com>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DISK_H
#define _DISK_H

#include <sys/ioctl.h>
#include <stdint.h>
#include <asm/ioctl.h>
#include <linux/fs.h>

#ifndef BLKGETSIZE
#define BLKGETSIZE _IO(0x12,96)      /* return device size */
#endif
#ifndef BLKSZGET
#define BLKSSZGET  _IO(0x12,104)       /* get block device sector size */
#endif
#ifndef BLKGETSIZE64
#define BLKGETSIZE64 _IOR(0x12,114,uint64_t)   /* return device size in bytes (u64 *arg) */
#endif
#ifndef BLKGETLASTSECT
#define BLKGETLASTSECT _IO(0x12,108) /* get last sector of block device */
#endif


enum _bus_type {bus_type_unknown, isa, pci};
enum _interface_type {interface_type_unknown,
		      ata, atapi, scsi, usb,
		      i1394, fibre, i2o, md,
		      virtblk, nvme};


unsigned int lcm(unsigned int x, unsigned int y);

int disk_get_pci(int fd,
		 int *interface_type,
		 unsigned char *bus,
		 unsigned char *device,
		 unsigned char *function);

struct disk_info {
	int interface_type;
	unsigned int controllernum;
	unsigned int disknum;
	unsigned char part;
	uint64_t major;
	unsigned char minor;
};

int disk_info_from_fd(int fd, struct disk_info *info);


int disk_get_partition_info (int fd, 
			     uint32_t num,
			     uint64_t *start, uint64_t *size,
			     char *signature,
			     uint8_t *mbr_type, uint8_t *signature_type);


int disk_get_size(int fd, long *size);
int get_sector_size(int fd);


#endif
